﻿using System;
using System.IO;
using RootPro.RootProCAD;

namespace RCAddInTableCalculationCS
{
    public partial class AppAddIn
    {
        // AddInSettingsクラスの保存XMLファイル名
        public string RC_AddInSettingsXmlFileName = "RCAddInTableCalculationSettings.xml";

        /// <summary>
        /// アドインの設定値クラス
        /// </summary>
        public class AddInSettings
        {
 
            /// <summary>
            /// コンストラクタ―
            /// </summary>
            public AddInSettings()
            {
                // クラスネーム（保存ファイルの先頭に書き出す）
                addinClassName = "RootPro CAD AddInProgram RCAddInTableCalculationSettings";

                // パラメータ初期値
                // 「計算モード」のパラメータス
                calcModeListParameterItemIndex = 0;
                // 係数」のパラメータの
                coefficientListParameterItemIndex = 0;
                // 「精度」のパラメータ
                precisionListParameterItemIndex = 2;
                // 「丸め」のパラメータ
                roundModeListParameterItemIndex = 0;
                // 「小数点以下のゼロ表記」のパラメータ
                zeroVisibleListParameterItemIndex = 0;
                // 「3桁区切り文字タイプ」のパラメータ
                separateTextTypeListParameterItemIndex = 0;
            }

            // クラスネーム（保存ファイルの先頭に書き出す）
            public string addinClassName;

            // コマンドパラメーターで保持する変数
            // 「計算モード」のパラメータで選択されていたもののインデックス
            public int calcModeListParameterItemIndex;
            // 係数」のパラメータで選択されていたもののインデックス
            public int coefficientListParameterItemIndex;
            // 「精度」のパラメータで選択されていたもののインデックス
            public int precisionListParameterItemIndex;
            // 「丸め」のパラメータで選択されていたもののインデックス
            public int roundModeListParameterItemIndex;
            // 「小数点以下のゼロ表記」のパラメータで選択されていたもののインデックス
            public int zeroVisibleListParameterItemIndex;
            // 「3桁区切り文字タイプ」のパラメータで選択されていたもののインデックス
            public int separateTextTypeListParameterItemIndex;
        }

        /// <summary>
        /// 設定値 AddInSettings をファイルに保存
        /// </summary>
        /// <param name="addInSettings"></param>
        public void SaveAddInSettings(AddInSettings addInSettings)
        {
            // アドインのファイルのある場所に保存
            string fileName = RC_AddInSettingsXmlFileName;
            string addInFullPath = AddInFullPath;
            string dir1 = Path.GetDirectoryName(addInFullPath);
            string filePathName = dir1 + "\\" + fileName;

            System.IO.StreamWriter sw = null;

            try
            {
                // 書き込むファイルを開く（UTF-8 BOM無し）
                sw = new System.IO.StreamWriter(filePathName, false, new System.Text.UTF8Encoding(false));

                // XmlSerializerオブジェクトを作成
                // AddInSettings
                System.Xml.Serialization.XmlSerializer serializer = new System.Xml.Serialization.XmlSerializer(typeof(AddInSettings));

                //シリアル化し、XMLファイルに保存する
                serializer.Serialize(sw, addInSettings);

                //ファイルを閉じる
                sw.Close();
            }
            catch(System.Exception)
            {
            }
            finally
            {
                if(sw != null)
                {
                    sw.Close();
                }
            }
        }

        /// <summary>
        /// 設定値 AddInSettings をファイルから読み込む
        /// </summary>
        /// <param name="addInSettings"></param>
        /// <returns></returns>
        public bool LoadAddInSettings(out AddInSettings addInSettings)
        {
            addInSettings = null;

            // アドインのファイルのある場所に保存
            string fileName = RC_AddInSettingsXmlFileName;
            string addInFullPath = AddInFullPath;
            string dir1 = Path.GetDirectoryName(addInFullPath);
            string filePathName = dir1 + "\\" + fileName;

            //読み込むファイルを開く
            System.IO.StreamReader sr = null;

            try
            {
                sr = new System.IO.StreamReader(filePathName, new System.Text.UTF8Encoding(false));

                //XmlSerializerオブジェクトを作成
                // AddInSettings
                System.Xml.Serialization.XmlSerializer serializer = new System.Xml.Serialization.XmlSerializer(typeof(AddInSettings));

                //XMLファイルから読み込み、逆シリアル化する
                addInSettings = (AddInSettings)serializer.Deserialize(sr);

                //ファイルを閉じる
                sr.Close();

                return true;
            }
            catch(System.Exception)
            {

            }
            finally
            {
                if(sr != null)
                {
                    sr.Close();
                }
            }

            return false;
        }
        
    }

}